import { CommonModule } from '@angular/common';
import { Component, Input, NgModule } from '@angular/core';
import { animation, style, animate, trigger, transition, useAnimation } from '@angular/animations';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';

const fadeIn = animation([
    style({ opacity: 0 }),
    animate('2s', style({ opacity: 1 }))
]);
const scaleIn = animation([
    style({ opacity: 0, transform: "scale(0.5)" }),
    animate('2s', style({ opacity: 1, transform: "scale(1)" }))
]);
class NgxDynamicCarouselComponent {
    constructor() {
        this.items = [];
        this.animationState = 'fade';
        this.visibleCount = 1;
        this.firstIndex = 0;
        this.lastIndex = this.visibleCount - 1;
    }
    ngOnInit() {
    }
    ngOnChanges(changes) {
        this.lastIndex = (changes === null || changes === void 0 ? void 0 : changes.visibleCount.currentValue) - 1;
    }
    right() {
        this.firstIndex = this.firstIndex + 1;
        this.lastIndex = this.lastIndex + 1;
    }
    left() {
        this.firstIndex = this.firstIndex - 1;
        this.lastIndex = this.lastIndex - 1;
    }
    trackByFn() {
        return Math.random();
    }
}
NgxDynamicCarouselComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-dynamic-carousel',
                template: "<div class=\"flex items-center justify-around\">\n    <div [class.disabled]=\"firstIndex == 0\" (click)=\"left()\">\n        <ng-container *ngTemplateOutlet=\"leftArrowTemplate ? leftArrowTemplate : defaultLeftArrowTemplate\">\n        </ng-container>\n        <ng-template #defaultLeftArrowTemplate>\n            <- </ng-template>\n    </div>\n    <div *ngFor=\"let item of items.slice(firstIndex, lastIndex + 1); index as i; trackBy: trackByFn\" [@animationTrigger]=\"animationState\">\n        <ng-template [ngTemplateOutlet]=\"mainContentTemplate\" [ngTemplateOutletContext]=\"{ $implicit: item }\">\n        </ng-template>\n    </div>\n\n    <div [class.disabled]=\"lastIndex == items.length - 1\" (click)=\"right()\">\n        <ng-container *ngTemplateOutlet=\"rightArrowtemplate ? rightArrowtemplate : defaultRightArrowTemplate\">\n        </ng-container>\n        <ng-template #defaultRightArrowTemplate>-></ng-template>\n    </div>\n</div>",
                animations: [
                    trigger('animationTrigger', [
                        transition('void=>scale', [
                            useAnimation(scaleIn)
                        ]),
                        transition('void=>fade', [
                            useAnimation(fadeIn)
                        ]),
                    ]),
                ],
                styles: [`
    .disabled {
      pointer-events: none;
      opacity: 50%
    }
    `]
            },] }
];
NgxDynamicCarouselComponent.ctorParameters = () => [];
NgxDynamicCarouselComponent.propDecorators = {
    mainContentTemplate: [{ type: Input }],
    leftArrowTemplate: [{ type: Input }],
    rightArrowtemplate: [{ type: Input }],
    items: [{ type: Input }],
    animationState: [{ type: Input }],
    visibleCount: [{ type: Input }]
};

class NgxDynamicCarouselModule {
}
NgxDynamicCarouselModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NgxDynamicCarouselComponent,
                ],
                imports: [
                    CommonModule,
                    BrowserAnimationsModule
                ],
                exports: [
                    NgxDynamicCarouselComponent,
                ]
            },] }
];

/*
 * Public API Surface of ngx-dynamic-carousel
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgxDynamicCarouselModule, fadeIn as ɵa, scaleIn as ɵb, NgxDynamicCarouselComponent as ɵc };
//# sourceMappingURL=ngx-dynamic-carousel.js.map
